CurrentWeather class

Annotations
  • @JsonSerializable.new()

Constructors

CurrentWeather(int? weathercode, double? temperature, DateTime? time, double? winddirection, double? windspeed)
CurrentWeather.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temperature double?
getter/setter pair
time DateTime?
getter/setter pair
weathercode int?
getter/setter pair
winddirection double?
getter/setter pair
windspeed double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited