DailyUnits class

Annotations
  • @JsonSerializable.new()

Constructors

DailyUnits(String? apparent_temperature_max, String? apparent_temperature_min, String? et0_fao_evapotranspiration, String? precipitation_hours, String? precipitation_sum, String? rain_sum, String? shortwave_radiation_sum, String? showers_sum, String? snowfall_sum, String? sunrise, String? sunrwindspeed_10m_maxise, String? sunset, String? temperature_2m_max, String? temperature_2m_min, String? weathercode, String? winddirection_10m_dominant, String? windgusts_10m_max)
DailyUnits.fromJson(Map<String, dynamic> json)
factory

Properties

apparent_temperature_max String?
getter/setter pair
apparent_temperature_min String?
getter/setter pair
et0_fao_evapotranspiration String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
precipitation_hours String?
getter/setter pair
precipitation_sum String?
getter/setter pair
rain_sum String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortwave_radiation_sum String?
getter/setter pair
showers_sum String?
getter/setter pair
snowfall_sum String?
getter/setter pair
sunrise String?
getter/setter pair
sunrwindspeed_10m_maxise String?
getter/setter pair
sunset String?
getter/setter pair
temperature_2m_max String?
getter/setter pair
temperature_2m_min String?
getter/setter pair
weathercode String?
getter/setter pair
winddirection_10m_dominant String?
getter/setter pair
windgusts_10m_max String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited