DailyWeather class

Annotations
  • @JsonSerializable.new()

Constructors

DailyWeather(List? time, List? weathercode, List? et0_fao_evapotranspiration, List? windgusts_10m_max, List? winddirection_10m_dominant, List? temperature_2m_min, List? temperature_2m_max, List? sunset, List? sunrise, List? snowfall_sum, List? showers_sum, List? shortwave_radiation_sum, List? rain_sum, List? precipitation_sum, List? precipitation_hours, List? apparent_temperature_min, List? apparent_temperature_max, List? windspeed_10m_max)
DailyWeather.fromJson(Map<String, dynamic> json)
factory

Properties

apparent_temperature_max List?
getter/setter pair
apparent_temperature_min List?
getter/setter pair
et0_fao_evapotranspiration List?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
precipitation_hours List?
getter/setter pair
precipitation_sum List?
getter/setter pair
rain_sum List?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortwave_radiation_sum List?
getter/setter pair
showers_sum List?
getter/setter pair
snowfall_sum List?
getter/setter pair
sunrise List?
getter/setter pair
sunset List?
getter/setter pair
temperature_2m_max List?
getter/setter pair
temperature_2m_min List?
getter/setter pair
time List?
getter/setter pair
weathercode List?
getter/setter pair
winddirection_10m_dominant List?
getter/setter pair
windgusts_10m_max List?
getter/setter pair
windspeed_10m_max List?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited