TimeZone class

If timezone is set, all timestamps are returned as local-time and data is returned starting at 00:00 local-time. Any time zone name from the time zone database https://en.wikipedia.org/wiki/List_of_tz_database_time_zones is supported. If auto is set as a time zone, the coordinates will be automatically resolved to the local time zone.

Constructors

TimeZone()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

africa_cairo → dynamic
no setter
america_anchorage → dynamic
no setter
america_chicago → dynamic
no setter
america_denver → dynamic
no setter
america_new_york → dynamic
no setter
america_sao_paulo → dynamic
no setter
asia_bangkok → dynamic
no setter
asia_tokyo → dynamic
no setter
australia_sydney → dynamic
no setter
auto → dynamic
no setter
europe_berlin → dynamic
no setter
europe_london → dynamic
no setter
europe_moscow → dynamic
no setter
pacific_auckland → dynamic
no setter