weather_open_meteo_client
library
Classes
-
CurrentWeather
-
-
DailyParam
-
-
DailyUnits
-
-
DailyWeather
-
-
Forecast
-
-
hourlyParam
-
-
HourlyUnits
-
-
HourlyWeather
-
-
Links
-
-
LocationList
-
-
OpenMeteoApi
-
-
PrecipitationUnit
-
Other precipitation amount units: mm, inch
-
TemperatureInit
-
If fahrenheit is set, all temperature values are converted to Fahrenheit.
-
TimeFormat
-
If format unixtime is selected, all time values are returned in UNIX epoch time in seconds. Please note that all timestamp are in GMT+0! For daily values with unix timestamps, please apply utc_offset_seconds again to get the correct date.
-
TimeZone
-
If timezone is set, all timestamps are returned as local-time and data is returned starting at 00:00 local-time.
Any time zone name from the time zone database
https://en.wikipedia.org/wiki/List_of_tz_database_time_zones
is supported. If auto is set as a time zone, the coordinates will be automatically resolved to the local time zone.
-
Weather
-
-
WindSpeedUnit
-
Other wind speed speed units:kmh, ms, mph and kn