DailyParam class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- apparent_temperature_max → dynamic
-
no setter
- apparent_temperature_min → dynamic
-
no setter
- et0_fao_evapotranspiration → dynamic
-
no setter
- precipitation_hours → dynamic
-
no setter
- precipitation_sum → dynamic
-
no setter
- rain_sum → dynamic
-
no setter
- shortwave_radiation_sum → dynamic
-
no setter
- showers_sum → dynamic
-
no setter
- snowfall_sum → dynamic
-
no setter
- sunrise → dynamic
-
no setter
- sunrwindspeed_10m_maxise → dynamic
-
no setter
- sunset → dynamic
-
no setter
- temperature_2m_max → dynamic
-
no setter
- temperature_2m_min → dynamic
-
no setter
- weathercode → dynamic
-
no setter
- winddirection_10m_dominant → dynamic
-
no setter
- windgusts_10m_max → dynamic
-
no setter