Forecast class
Constructors
-
Forecast({required double latitude, required double longitude, String? timezone, List<String>? daily, bool? current_weather, List<String>? hourly, String? end_date, int? past_days, String? precipitation_unit, String? start_date, String? temperature_unit, String? timeformat, String? windspeed_unit})
-
Properties
-
current_weather
↔ bool?
-
Default false. Include current weather conditions
getter/setter pair
-
daily
↔ List<String>?
-
A list of daily weather variable aggregations which should be returned. If daily weather variables are specified, parameter timezone is required.
getter/setter pair
-
end_date
↔ String?
-
The time interval to get weather data. A day must be specified as an ISO8601 date (e.g. 2022-06-30).
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hourly
↔ List<String>?
-
A list of weather variables which should be returned.
getter/setter pair
-
latitude
↔ double
-
Geographical WGS84 coordinate of the location
getter/setter pair
-
longitude
↔ double
-
Geographical WGS84 coordinate of the location
getter/setter pair
-
past_days
↔ int?
-
Default 0. If past_days is set, yesterday or the day before yesterday data are also returned.
getter/setter pair
-
precipitation_unit
↔ String?
-
Default mm. Other precipitation amount units: inch
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
start_date
↔ String?
-
The time interval to get weather data. A day must be specified as an ISO8601 date (e.g. 2022-06-30).
getter/setter pair
-
temperature_unit
↔ String?
-
Default celsius. If fahrenheit is set, all temperature values are converted to Fahrenheit.
getter/setter pair
-
timeformat
↔ String?
-
getter/setter pair
-
timezone
↔ String?
-
Default GMT. If auto is set as a time zone, the coordinates will be automatically resolved to the local time zone.
getter/setter pair
-
windspeed_unit
↔ String?
-
Default kmh. Other wind speed speed units: ms, mph and kn
getter/setter pair