timezone property
Default GMT. If auto is set as a time zone, the coordinates will be automatically resolved to the local time zone.
Implementation
String? timezone=TimeZone.auto;
Default GMT. If auto is set as a time zone, the coordinates will be automatically resolved to the local time zone.
String? timezone=TimeZone.auto;