OpenMeteoApi class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getWeatherByCityName(String query)
→ Future<Weather>
-
-
getWeatherByCoordinate({required double latitude, required double longitude, List<String>? hourly, List<String>? daily, bool current_weather = false, String? temperature_unit, String? windspeed_unit, String? precipitation_unit, String? timeformat, String? timezone, int? past_days = 0, String? start_date = '', String? end_date = ''})
→ Future<Weather>
-
-
locationSearch(String query)
→ Future<LocationList>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited