Weather class
- Annotations
-
- @JsonSerializable.new()
Constructors
- Weather({required double? latitude, required double? longitude, HourlyWeather? hourly, CurrentWeather? current_weather, DailyWeather? daily, DailyUnits? daily_units, double? elevation, double? generationtime_ms, HourlyUnits? hourly_units, String? timezone, String? timezone_abbreviation, int? utc_offset_seconds})
-
Weather.fromJson(Map<
String, dynamic> json) -
factory
Properties
- current_weather ↔ CurrentWeather?
-
getter/setter pair
- daily ↔ DailyWeather?
-
getter/setter pair
- daily_units ↔ DailyUnits?
-
getter/setter pair
- elevation ↔ double?
-
getter/setter pair
- generationtime_ms ↔ double?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hourly ↔ HourlyWeather?
-
getter/setter pair
- hourly_units ↔ HourlyUnits?
-
getter/setter pair
- latitude ↔ double?
-
getter/setter pair
- longitude ↔ double?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timezone ↔ String?
-
getter/setter pair
- timezone_abbreviation ↔ String?
-
getter/setter pair
- utc_offset_seconds ↔ int?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited